@@ -2,6 +2,7 @@
 
 import clr
 import System
+clr.AddReference('System.Net.Security')
 clr.AddReference('System.IO.FileSystem.Watcher')
 clr.AddReference('PrimaITestCaseLibrary')
 clr.AddReference('PrimaTestCaseLibrary')
@@ -237,6 +238,14 @@ from PrimaITestCaseLibrary.MessageManagment import IMessageDlt as MessageDlt
 from PrimaITestCaseLibrary.MessageManagment import IMessageDltStandardHeader as DltStandardHeader
 from PrimaITestCaseLibrary.MessageManagment import IMessageDltExtendedHeader as DltExtendedHeader
 from PrimaITestCaseLibrary.MessageManagment import DltType as DltType
+from PrimaITestCaseLibrary.MessageManagment import IMessageTls as MessageTls
+from PrimaITestCaseLibrary.MessageManagment import TlsContentTypes as TlsContentTypes
+from PrimaITestCaseLibrary.MessageManagment import ITlsHandshake as ITlsHandshake
+from PrimaITestCaseLibrary.MessageManagment import HandshakeTypes as HandshakeTypes
+from PrimaITestCaseLibrary.MessageManagment import TlsCipherSuite as TlsCipherSuite
+from PrimaITestCaseLibrary.MessageManagment import ITlsAlert as ITlsAlert
+from PrimaITestCaseLibrary.MessageManagment import AlertLevels as AlertLevels
+from PrimaITestCaseLibrary.MessageManagment import AlertDescription as AlertDescription
 from PrimaITestCaseLibrary.MessageManagment import IMessageICMPv6 as MessageICMPv6
 from PrimaITestCaseLibrary.MessageManagment import ICMPv6_TYPE as ICMPv6_TYPE
 from PrimaITestCaseLibrary.MessageManagment import IMessageSRP as MessageSRP
